@@ -68,6 +68,12 @@
 #include <unistd.h>
 #endif
 
+#if __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ > 4)
+#define G_GNUC_UNUSED __attribute__((__unused__))
+#else
+#define G_GNUC_UNUSED
+#endif
+
 #include <tdb/tdb.h>
 
 /* a tdb tool for manipulating a tdb database */
@@ -419,7 +425,8 @@ static void next_record(TDB_CONTEXT *context, TDB_DATA *pkey)
 
 int main(int argc, char *argv[])
 {
-    int bIterate = 0, ignore;
+    int bIterate = 0;
+    int ignore G_GNUC_UNUSED;
     char *line;
     char *tok;
   TDB_DATA iterate_kbuf;
@@ -482,9 +489,9 @@ int main(int argc, char *argv[])
             delete_tdb();
         } else if (strcmp(tok,"dump") == 0) {
             bIterate = 0;
-      if(open_dump_file() == 0) { //open file
+      if(open_dump_file() == 0) { /* open file */
         tdb_traverse(tdb, print_rec, NULL);
-        close_dump_file(); //close file
+        close_dump_file(); /* close file */
       }
       pDumpFile = stdout;
         } else if (strcmp(tok,"list") == 0) {
